@@ -13,11 +13,9 @@ from nltk.stem.porter import PorterStemmer
 from nltk.stem import WordNetLemmatizer
 from gensim.utils import lemmatize, simple_preprocess
 import spacy
+import pandas as pd
 
-def get_text_english(list_doc):
-    return singularize(list_doc)
-
-def singularize(text,min_count=5,threshold=100):
+def get_text_english(text,min_count=5,threshold=100,use_bigram=False):
     from nltk.corpus import stopwords
     stop_words = stopwords.words('english')
     def sent_to_words(sentences):
@@ -60,7 +58,6 @@ def singularize(text,min_count=5,threshold=100):
     data_ready = process_words(data_words,stop_words=stop_words,allowed_postags=allowed_postags)  # processed Text Data!
     return data_ready
 
-
 def get_text_chinese(list_doc,stopwords_path):
     stopwords=[]
     if os.path.exists(stopwords_path):
@@ -99,7 +96,7 @@ def get_text_chinese(list_doc,stopwords_path):
         texts.append(tokens)
     return texts
 
-def LDA(field,list_doc,weights_path,list_keywods_path,stopwords_path,num_topics=6,num_words=50,num_pass=5,lang='zh'):
+def LDA(field,list_doc,weights_path,list_keywods_path,stopwords_path,num_topics=6,num_words=50,num_pass=5,lang='zh',use_bigram=False,iteration=100,random_state=100,chunk_size=10):
 
     # ============ begin configure ====================
     NUM_TOPICS = num_topics
@@ -122,7 +119,9 @@ def LDA(field,list_doc,weights_path,list_keywods_path,stopwords_path,num_topics=
                 jieba.add_word(w,1)
         texts=get_text_chinese(list_doc,stopwords_path=stopwords_path)
     else:
-        texts=get_text_english(list_doc)
+        texts=get_text_english(list_doc,use_bigram=use_bigram)
+
+
 
     # turn our tokenized documents into a id <-> term dictionary
     dictionary = corpora.Dictionary(texts)
@@ -131,14 +130,49 @@ def LDA(field,list_doc,weights_path,list_keywods_path,stopwords_path,num_topics=
     corpus = [dictionary.doc2bow(text) for text in texts]
 
     # generate LDA model
-    ldamodel = gensim.models.ldamodel.LdaModel(corpus, num_topics=NUM_TOPICS, id2word=dictionary, passes=NUM_PASS)
+    ldamodel = None
+
+    if lang=='en':
+        ldamodel = gensim.models.ldamodel.LdaModel(corpus,
+                                                   num_topics=NUM_TOPICS,
+                                                   id2word=dictionary,
+                                                   passes=NUM_PASS,
+                                                   random_state=random_state,
+                                                   update_every=1,
+                                                   chunksize=chunk_size,
+                                                   alpha='symmetric',
+                                                   iterations=iteration,
+                                                   per_word_topics=True
+                                                   )
+    elif lang=='zh':
+        ldamodel = gensim.models.ldamodel.LdaModel(corpus,
+                                                   num_topics=NUM_TOPICS,
+                                                   id2word=dictionary,
+                                                   passes=NUM_PASS,
+                                                   random_state=random_state,
+                                                   update_every=1,
+                                                   chunksize=chunk_size,
+                                                   alpha='symmetric',
+                                                   iterations=iteration,
+                                                   per_word_topics=True
+                                                   )
 
     # print keywords
     topics = ldamodel.print_topics(num_words=NUM_WORDS, num_topics=NUM_TOPICS)
 
-    save_topic_weights(field,topics,weights_path)
+    dict_topic_weights=get_topic_distribution(lda_model=ldamodel,corpus=corpus)
+    # save keywords weights
+    save_keywords_weights(field,topics,weights_path)
+    # save topic weights
+    save_topic_weights(field,dict_topic_weights,weights_path)
 
-def save_topic_weights(field,topics,weights_path):
+def save_topic_weights(field,weights,weights_path):
+    f_out_w = open(f"{weights_path}/{field}_w.csv", 'w', encoding='utf-8')
+    for k in weights:
+        f_out_w.write(f"{k},{weights[k]}\n")
+    f_out_w.close()
+
+def save_keywords_weights(field,topics,weights_path):
     f_out_k=open(f"{weights_path}/{field}_k.csv",'w',encoding='utf-8')
     f_out_v = open(f"{weights_path}/{field}_v.csv", 'w', encoding='utf-8')
     for topic in topics:
@@ -161,6 +195,7 @@ def save_topic_weights(field,topics,weights_path):
     f_out_v.close()
     f_out_k.close()
 
+
 def lda_by_tag_each(list_category,root_path,weights_path,list_keywords_path,stopwords_path,minimum_num_doc=15,num_topics=6,num_pass=5,num_words=50,lang='zh'):
     if not os.path.exists(weights_path):
         os.mkdir(weights_path)
@@ -180,3 +215,48 @@ def lda_by_tag_each(list_category,root_path,weights_path,list_keywords_path,stop
             print(country,len(list_doc))
             LDA(country, list_doc,weights_path,list_keywords_path,stopwords_path,num_topics,num_words,num_pass,lang=lang)
         print()
+
+def get_topic_distribution(lda_model,corpus):
+    # Sentence Coloring of N Sentences
+    def topics_per_document(model, corpus, start=0, end=1):
+        corpus_sel = corpus[start:end]
+        dominant_topics = []
+        topic_percentages = []
+        for i, corp in enumerate(corpus_sel):
+            topic_percs, wordid_topics, wordid_phivalues = model[corp]
+            dominant_topic = sorted(topic_percs, key=lambda x: x[1], reverse=True)[0][0]
+            dominant_topics.append((i, dominant_topic))
+            topic_percentages.append(topic_percs)
+        return dominant_topics, topic_percentages
+
+    dominant_topics, topic_percentages = topics_per_document(model=lda_model, corpus=corpus, end=-1)
+
+    # Distribution of Dominant Topics in Each Document
+    df = pd.DataFrame(dominant_topics, columns=['Document_Id', 'Dominant_Topic'])
+    dominant_topic_in_each_doc = df.groupby('Dominant_Topic').size()
+    df_dominant_topic_in_each_doc = dominant_topic_in_each_doc.to_frame(name='count').reset_index()
+
+
+    # df_dominant_topic_in_each_doc.to_csv(output_folder + "/" + save_dominant_topic_file, encoding='utf-8')
+
+    # Total Topic Distribution by actual weight
+    topic_weightage_by_doc = pd.DataFrame([dict(t) for t in topic_percentages])
+    df_topic_weightage_by_doc = topic_weightage_by_doc.sum().to_frame(name='count').reset_index()
+
+    # df_topic_weightage_by_doc.to_csv(output_folder + "/" + save_topic_topic_weight, encoding='utf-8')
+    total_weight=0
+    for idx,row in df_topic_weightage_by_doc.iterrows():
+        # print(row)
+        index =row["index"]
+        count=row["count"]
+        total_weight+=count
+
+    list_item={}
+    for idx,row in df_topic_weightage_by_doc.iterrows():
+        # print(row)
+        index =row["index"]
+        count=row["count"]
+        # list_item[index]=round(count*1.0/total_weight,6)
+        list_item[index]=count
+    return list_item
+
