@@ -18,18 +18,20 @@ def get_trends(start_year,end_year, label_names,list_topics, root_path="results/
             continue
         k_lines = open(f"{root_path}/{year}_k.csv", 'r', encoding='utf-8').readlines()
         v_lines = open(f"{root_path}/{year}_v.csv", 'r', encoding='utf-8').readlines()
+        w_lines=open(f"{root_path}/{year}_w.csv", 'r', encoding='utf-8').readlines()
         for idx, item in enumerate(k_lines):
             fs_k = item.strip().split(",")
             fs_v = v_lines[idx].strip().split(",")
+            topic_weight=float(w_lines[idx].strip().split(",")[1])
             for kid, k in enumerate(fs_k):
                 weight = float(fs_v[kid])
                 keyword = k
                 if keyword not in list_all_words:
                     list_all_words.append(keyword)
                 if keyword not in dict_keyword.keys():
-                    dict_keyword[keyword] = [weight]
+                    dict_keyword[keyword] = [topic_weight*weight]
                 else:
-                    dict_keyword[keyword].append(weight)
+                    dict_keyword[keyword].append(topic_weight*weight)
         list_year_v.append(year)
         list_year.append(dict_keyword)
 
