@@ -7,19 +7,21 @@ def load_topic_file(output_folder, topic_name,top=10):
     dict_keyword_weights={}
     k_lines = open(f"{output_folder}/{topic_name}_k.csv", 'r', encoding='utf-8').readlines()
     v_lines = open(f"{output_folder}/{topic_name}_v.csv", 'r', encoding='utf-8').readlines()
+    w_lines = open(f"{output_folder}/{topic_name}_w.csv", 'r', encoding='utf-8').readlines()
     dict_keyword=OrderedDict()
     for idx, item in enumerate(k_lines):
         fs_k = item.strip().split(",")
         fs_v = v_lines[idx].strip().split(",")
+        topic_weight=float(w_lines[idx].strip().split(",")[1])
         for kid, k in enumerate(fs_k):
             weight = float(fs_v[kid])
             keyword = k
             #if keyword not in list_all_words:
             #    list_all_words.append(keyword)
             if keyword not in dict_keyword_weights.keys():
-                dict_keyword_weights[keyword] = [weight]
+                dict_keyword_weights[keyword] = [topic_weight * weight]
             else:
-                dict_keyword_weights[keyword].append(weight)
+                dict_keyword_weights[keyword].append(topic_weight * weight)
     for k in dict_keyword_weights:
         dict_keyword[k]=np.sum(dict_keyword_weights[k])
     dict_keyword = OrderedDict(sorted(dict_keyword.items(), key=lambda obj: obj[1], reverse=True))
