@@ -1,7 +1,7 @@
 from quickcsv.file import *
 import os
 
-def divide_by_year(meta_csv_file,raw_text_folder,output_folder,start_year=2000,end_year=2021,tag_field="Tag",time_field="PublishTime",id_field="FileId"):
+def divide_by_year(meta_csv_file,raw_text_folder,output_folder,start_year=2000,end_year=2021,tag_field="Tag",time_field="PublishTime",id_field="FileId",prefix_filename=''):
     count = 0
     if not os.path.exists(output_folder):
         os.mkdir(output_folder)
@@ -17,6 +17,8 @@ def divide_by_year(meta_csv_file,raw_text_folder,output_folder,start_year=2000,e
         year=''
         if '-' in pubtime:
             year=pubtime.split("-")[0]
+        else:
+            year=pubtime
         if year.strip()=="":
             continue
         if int(year)<start_year or int(year)>end_year:
@@ -24,7 +26,7 @@ def divide_by_year(meta_csv_file,raw_text_folder,output_folder,start_year=2000,e
 
         # file id
         file_id = item[id_field]
-        text_path = f"{raw_text_folder}/{file_id}.txt"
+        text_path = f"{raw_text_folder}/{prefix_filename}{file_id}.txt"
         if not os.path.exists(text_path):
             continue
         text = open(text_path, 'r', encoding='utf-8').read()
